Stan Math Library: stan/math/prim/mat/fun/typedefs.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

typedefs.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_MAT_FUN_TYPEDEFS_HPP
2 #define STAN_MATH_PRIM_MAT_FUN_TYPEDEFS_HPP
3
4 #include <stan/math/prim/mat/fun/Eigen.hpp>
5 #include <stan/math/prim/mat/meta/index_type.hpp>
6
7 namespace stan {
8
9 namespace math {
10
14 typedef
15 index_type<Eigen::Matrix<double, Eigen::Dynamic, Eigen::Dynamic> >::type
16 size_type;
17
21 typedef
22 Eigen::Matrix<double, Eigen::Dynamic, Eigen::Dynamic>
23 matrix_d;
24
28 typedef
29 Eigen::Matrix<double, Eigen::Dynamic, 1>
30 vector_d;
31
35 typedef
36 Eigen::Matrix<double, 1, Eigen::Dynamic>
37 row_vector_d;
38
39 }
40 }
41
42 #endif
stan::math::vector_d
Eigen::Matrix< double, Eigen::Dynamic, 1 > vector_d
Type for (column) vector of double values.
Definition: typedefs.hpp:30
stan
Definition: log_sum_exp.hpp:8
stan::math::row_vector_d
Eigen::Matrix< double, 1, Eigen::Dynamic > row_vector_d
Type for (row) vector of double values.
Definition: typedefs.hpp:37
stan::math::size_type
Eigen::Matrix< double, Eigen::Dynamic, Eigen::Dynamic >::Index size_type
Type for sizes and indexes in an Eigen matrix with double e.
Definition: typedefs.hpp:13
index_type.hpp
Eigen.hpp
stan::math::matrix_d
Eigen::Matrix< double, Eigen::Dynamic, Eigen::Dynamic > matrix_d
Type for matrix of double values.
Definition: typedefs.hpp:23

[ Stan Home Page ] © 2011–2016, Stan Development Team.